@@ -7,7 +7,7 @@ from xlsx_lib.domain.generic_replacements.replacement_part import ReplacementPar
 
 # TODO: To dataclass with Optional[list[ReplacementPart]]
 class Replacement(CamelModel):
-    name: str
+    name: Optional[str]
     reference: Optional[str]
     observations: Optional[str]
     parts: Optional[List[ReplacementPart]]
